# Table of Contents

- [ai-governance-and-adoption-collect-information](<./ai-governance-and-adoption-collect-information.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 1: Collect Data](<./Step-1-Collect-Data.md>)
  - [Add Initial Data](<./Step-1-Collect-Data/Add-Initial-Data.md>)
  - [Collect Data from Experts](<./Step-1-Collect-Data/Collect-Data-from-Experts.md>)
  - [Required Data](<./Step-1-Collect-Data/Required-Data.md>)
